<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // exit if access directly.
}

if ( ( class_exists( 'LearnDash_Settings_Section' ) ) && ( ! class_exists( 'LearnDash_Upsells_Settings_Fields' ) ) ) {
	/**
	 * Class LearnDash Settings Section for Custom Labels Metabox.
	 */
	class LearnDash_Upsells_Settings_Fields extends LearnDash_Settings_Section {

		/**
		 * Protected constructor for class
		 */
		protected function __construct() {
			$this->settings_page_id = 'ldups_upsell_settings';

			// This is the 'option_name' key used in the wp_options table.
			$this->setting_option_key = 'ldups_upsells';

			// This is the HTML form field prefix used.
			$this->setting_field_prefix = 'ldups_upsells';

			// Used within the Settings API to uniquely identify this section.
			$this->settings_section_key = 'upsells_custom_fields';

			// Section label/header.
			$this->settings_section_label = esc_html__( 'UpSells', 'ldups_upsells' );

			$this->settings_section_description = esc_html__( 'UpSells For LearnDash Settings', 'ldups_upsells' );

			parent::__construct();
		}

		/**
		 * Initialize the metabox settings values.
		 */
		public function load_settings_values() {
			parent::load_settings_values();

			if ( false === $this->setting_option_values ) {
				$this->setting_option_values = get_option( 'learndash_custom_label_settings' );
			}

			if ( ( isset( $_GET['action'] ) ) && ( 'ld_reset_settings' === $_GET['action'] ) && ( isset( $_GET['page'] ) ) && ( $_GET['page'] === $this->settings_page_id ) ) {
				if ( ( isset( $_GET['ld_wpnonce'] ) ) && ( ! empty( $_GET['ld_wpnonce'] ) ) ) {
					if ( wp_verify_nonce( $_GET['ld_wpnonce'], get_current_user_id() . '-' . $this->setting_option_key ) ) {
						if ( ! empty( $this->setting_option_values ) ) {
							foreach ( $this->setting_option_values as $key => $val ) {
								$this->setting_option_values[ $key ] = '';
							}
							$this->save_settings_values();
						}

						$reload_url = remove_query_arg( array( 'action', 'ld_wpnonce' ) );
						learndash_safe_redirect( $reload_url );
					}
				}
			}
		}

		/**
		 * Initialize the metabox settings fields.
		 */
		public function load_settings_fields() {
			$this->setting_option_fields = array(

				// enroller count switch.
				'enrolled_count'  => array(
					'name'      => 'enrolled_count',
					'type'      => 'checkbox-switch',
					'label'     => esc_html__( 'Display enroll count for the course', 'ldups-upells' ),
					'help_text' => esc_html__( 'Shows a count of users (who enrolled for that course) next to each course in the UpSell widget.', 'ldups-upells' ),
					'value'     => $this->setting_option_values['enrolled_count'],
					'options'   => array(
						'yes' => '',
					),
				),

				// upsells widget heading.
				'upsells_heading' => array(
					'name'      => 'upsells_heading',
					'type'      => 'text',
					'default'   => 'Students also bought',
					'label'     => esc_html__( 'UpSells Widget Title', 'ldups-upsells' ),
					'help_text' => esc_html__( 'Use this setting to give a suitable heading to your UpSell widget.', 'ldups-upsells' ),
					'value'     => '' !== $this->setting_option_values['upsells_heading'] ? $this->setting_option_values['upsells_heading'] : 'Students also bought',
				),
			);

			/**
			 * Filters custom labels setting fields.
			 *
			 * @param array $setting_option_fields Associative array of Setting field details like name,type,label,value.
			 */
			$this->setting_option_fields = apply_filters( 'learndash_custom_label_fields', $this->setting_option_fields );

			$this->setting_option_fields = apply_filters( 'learndash_settings_fields', $this->setting_option_fields, $this->settings_section_key );

			parent::load_settings_fields();
		}

		/**
		 * Save settings
		 *
		 * @param array  $new_values         Array of section fields values.
		 * @param array  $old_values         Array of old values.
		 * @param string $setting_option_key Section option key should match $this->setting_option_key.
		 */
		public function section_pre_update_option( $new_values = '', $old_values = '', $setting_option_key = '' ) {
			if ( $setting_option_key === $this->setting_option_key ) {
				$new_values = parent::section_pre_update_option( $new_values, $old_values, $setting_option_key );

				// cheks the index of all the fields and update the default value.
				if ( $new_values !== $old_values ) {

					// sets the default option for enroller count.
					if ( ! isset( $new_values['enrolled_count'] ) ) {
						$new_values['enrolled_count'] = '';
					}

					// set the default upsell heading.
					if ( ! isset( $new_values['upsells_heading'] ) ) {
						$new_values['upsells_heading'] = 'Students also bought';
					}
				}
			}
			return $new_values;
		}
	}
}
add_action(
	'learndash_settings_sections_init',
	function () {
		LearnDash_Upsells_Settings_Fields::add_section_instance();
	}
);
