<?php
/**
 * Plugin Name: UpSells For LearnDash
 * Description: UpSells for LearnDash allows you to create a widget on LearnDash course page that enables you to display other related courses of your choice. It enables you to  increase visibility of your higher end course offerings to your customers and thus driving more sales.
 * Plugin URI:  https://www.saffiretech.com/upsells-for-learndash/
 * Author URI:  https://www.saffiretech.com
 * Author:      SaffireTech
 * Text Domain: ldups-upsells
 * Domain Path: /languages
 * Requires at least: 5.3
 * Tested up to: 6.1.1
 * Requires PHP: 7.4
 * LD Requires at least: 3.6.0.3
 * LD tested up to: 4.4.0.1
 * License:     GPLv3
 * License URI: URI: https://www.gnu.org/licenses/gpl-3.0.html
 * Version:     1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit(); // Exit if accessed directly.
}

/**
 * Check the installation of pro version.
 *
 * @return bool
 */
function ldups_upsells_check_pro_version() {
	require_once ABSPATH . 'wp-admin/includes/plugin.php';
	if ( is_plugin_active( 'upsells-for-learndash-pro/upsells-for-learndash-pro.php' ) ) {
		return true;
	} else {
		return false;
	}
}

/**
 * Display notice if pro plugin found.
 */
function ldups_upsells_free_plugin_install() {

	// if pro plugin found deactivate free plugin.
	if ( ldups_upsells_check_pro_version() ) {
		deactivate_plugins( plugin_basename( __FILE__ ), true );
		if ( defined( 'LDUPS_PRO_PLUGIN' ) ) {
			if ( isset( $_GET['activate'] ) ) {
				unset( $_GET['activate'] );
			}
			add_action( 'admin_notices', 'ldups_upsells_install_free_admin_notice' );
		}
	}
}
add_action( 'plugins_loaded', 'ldups_upsells_free_plugin_install' );

/**
 * Add message if paid version is installed.
 */
function ldups_upsells_install_free_admin_notice() {
	?>
	<div class="notice notice-error is-dismissible">
		<p><?php esc_html_e( 'Free version deactivated', 'ldups-upsells' ); ?></p>
	</div>
	<?php
}

/**
 * Loads upsells settings files.
 */
function ldups_upsells_free_load_settings_page() {
	if ( ! ldups_upsells_check_pro_version() ) {
		require_once dirname( __FILE__ ) . '/include/ldups-upsells-class-setting-page.php';
		require_once dirname( __FILE__ ) . '/include/ldups-upsells-class-setting-fields.php';
	}
}
add_action( 'plugins_loaded', 'ldups_upsells_free_load_settings_page' );

/**
 * Loads required js & css file.
 */
function ldups_upsells_free_load_css_js_files() {
	if ( ! ldups_upsells_check_pro_version() ) {
		require_once dirname( __FILE__ ) . '/include/ldups-upsells-metabox.php'; // metabox display.
		require_once dirname( __FILE__ ) . '/include/ldups-upsells-widget.php'; // upsell widget display.
		wp_enqueue_script( 'jquery' );
		wp_enqueue_style( 'ldups-upsells-course-css', plugins_url( 'assets/css/ldups-upsells-courses.css', __FILE__ ), array(), '1.0.0' );
		wp_enqueue_style( 'ldups-upsells-select2-css', plugins_url( 'assets/css/select2.min.css', __FILE__ ), array(), '1.1.0' );
		wp_enqueue_style( 'ldups-upsells-slick-css', 'https://cdnjs.cloudflare.com/ajax/libs/slick-carousel/1.8.1/slick.min.css', array(), '1.1.0' );
		wp_enqueue_style( 'ldups-upsells-group-css', esc_url( 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css' ), array(), '1.0.0' );
		wp_enqueue_script( 'ldups-upsells-course-js', plugins_url( 'assets/js/ldups-upsells-courses.js', __FILE__ ), array( 'jquery' ), '1.0.0', false );
		wp_enqueue_script( 'ldups-upsells-slick-js', 'https://cdnjs.cloudflare.com/ajax/libs/slick-carousel/1.8.1/slick.min.js', array( 'jquery' ), '1.0.0', false );
		wp_enqueue_script( 'ldups-upsells-select2-js', plugins_url( 'assets/js/select2.min.js', __FILE__ ), array( 'jquery' ), '1.1.0', false );
		wp_localize_script(
			'ldups-upsells-course-js',
			'ldups_data',
			array(
				'ajaxurl' => admin_url( 'admin-ajax.php' ),
				'nonce'   => wp_create_nonce( 'ldups-upsells' ),
			)
		);
		load_plugin_textdomain( 'ldups-upsells', false, basename( dirname( __FILE__ ) ) . '/languages/' );
		wp_enqueue_script( 'ldups-upsells-customscript-js', plugins_url( 'assets/js/custom-script.js', __FILE__ ), array( 'jquery' ), '1.1.0', false );
	}
}
add_action( 'init', 'ldups_upsells_free_load_css_js_files' );

/**
 * Settings link on plugin page.
 *
 * @param array $links links Plugin links on plugins.php.
 * @return array
 */
function ldups_upsells_free_action_links_callback( $links ) {
	if ( ! ldups_upsells_check_pro_version() ) {
		$settinglinks = array(
			'<a href="' . admin_url( 'admin.php?page=ldups_upsell_settings' ) . '">' . __( 'Setting', 'ldups-upsells' ) . '</a>',
		);
		return array_merge( $settinglinks, $links );
	} else {
		return $links;
	}
}
add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'ldups_upsells_free_action_links_callback', 10, 1 );
